@@ -1,14 +1,31 @@
 from typing import Tuple
 
 import numpy as np
+import os
 from pyspark.sql import DataFrame
 
 
-class ModelInterface:
+class BaseModel:
     """
     Sets of interfaces that need to be implemented to provide a new version of the NextItemPredictor model
     """
 
+    def load_or_build_dataset(self):
+        if os.path.exists("/tmp/dataset.parquet"):
+            print("Loading dataset from /tmp/dataset.parquet")
+            from pyspark.sql.session import SparkSession
+
+            spark = SparkSession.builder.getOrCreate()
+
+            return spark.read.parquet("/tmp/dataset.parquet")
+
+        df = self.build_dataset(debug=False)
+
+        df = df.drop("uuid")
+        df.write.parquet("/tmp/dataset.parquet")
+
+        return df
+
     def build_dataset(self) -> DataFrame:
         """
         Builds a dataset for the NextItemPredictor model.
